@@ -1,8 +1,7 @@
-as.wmppp.ppp <-
-function(X, ...) 
-{
+as.wmppp.ppp <- function(X, ...) {
+
   Marks <- marks(X)
-  
+
   # Marks are a dataframe with colums PointType and PointWeight
   if (is.data.frame(Marks)) {
     names(Marks) <- tolower(names(Marks))
@@ -12,15 +11,15 @@ function(X, ...)
     }
     if (!is.factor(PointType))  {
       PointType <- as.factor(PointType)
-    }    
+    }
     if ("pointweight" %in% names(Marks)) {
       PointWeight <- Marks[, "pointweight"]
-    }      
+    }
     if (!is.numeric(PointWeight))  {
       stop("Point weights have been found in the marks of the point pattern but they must be numeric.")
-    }    
+    }
   } else {
-    # Marks are types, set types to "All"  
+    # Marks are types, set types to "All"
     if (is.factor(Marks)) {
       PointType <- Marks
     } else {
@@ -37,9 +36,9 @@ function(X, ...)
   if (any(PointWeight < 0)) {
     stop("Point weights must be positive.")
   }
-  
+
   wmpppX <- X
   marks(wmpppX) <- data.frame(PointWeight, PointType)
   class(wmpppX) <- c("wmppp", "ppp")
-  return (wmpppX)
+  return(wmpppX)
 }
